import path from 'path';
const filterCollections = [];
const presets = [];
/**
 * This function loads an addon by its name.
 * @param addonName The name of the addon to be loaded.
 */
async function loadAddon(addonName) {
    console.log(`loading addon "${addonName}"`);
    const resolve_paths = require.main?.paths ?? [];
    let cwd_path = process.cwd();
    while (cwd_path !== '/') {
        resolve_paths.push(cwd_path + '/node_modules');
        cwd_path = path.dirname(cwd_path);
    }
    const addon_path = require.resolve(addonName, {
        paths: require.main?.paths,
    });
    console.log(`addon path: ${addon_path}`);
    const addon = (await import(addon_path)).default;
    filterCollections.push(...addon.filterCollections.map(fc => {
        return {
            ...fc,
            name: addonName + ':filter_collection:' + fc.name,
        };
    }));
    presets.push(...addon.presets.map(p => {
        return {
            ...p,
            name: addonName + ':preset:' + p.name,
        };
    }));
    return;
}
/**
 * This function activates a filter collection by its name.
 * @param filterCollectionName The name of the filter collection to be activated.
 * @param env The nunjucks environment into which the filters should be loaded.
 */
export async function activateFilterCollection(filterCollectionName, env) {
    let filterCollection = filterCollections.find(fc => fc.name === filterCollectionName);
    if (!filterCollection) {
        await loadAddon(filterCollectionName.split(':')[0]);
        filterCollection = filterCollections.find(fc => fc.name === filterCollectionName);
        if (!filterCollection)
            throw new Error(`Could not find filter collection "${filterCollectionName}"`);
    }
    filterCollection.filters.forEach(f => {
        env.addFilter(f.name, f.function);
    });
}
/**
 * This function returns a preset by its name.
 * @param presetName The name of the Preset.
 */
export async function loadPreset(presetName) {
    let preset = presets.find(p => p.name === presetName);
    if (!preset) {
        await loadAddon(presetName.split(':')[0]);
        preset = presets.find(p => p.name === presetName);
        if (!preset)
            throw new Error(`Could not find preset "${presetName}`);
    }
    return preset;
}
/**
 * This function activates a preset.
 * @param preset The Preset to be activated.
 * @param env The nunjucks environment the filters, tests and globals of the preset
 * should be loaded into.
 */
export async function activatePreset(preset, env) {
    preset.filterCollections.forEach(fc => {
        fc.filters.forEach(f => {
            env.addFilter(f.name, f.function);
        });
    });
    preset.globals.forEach(g => {
        env.addGlobal(g.name, g.value);
    });
    preset.tests.forEach(t => {
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        env.addTest(t.name, t.function);
    });
    env.addGlobal('templateDir', preset.templatesDir);
}
//# sourceMappingURL=addon.js.map