import nunjucks from 'nunjucks';
/**
 * Interface for an addon.
 */
export interface Addon {
    /**
     * Filter collections provided by the addon.
     */
    filterCollections: FilterCollection[];
    /**
     * Presets provided by the addon.
     */
    presets: Preset[];
}
/**
 * Interface for a filter collection.
 */
export interface FilterCollection {
    /**
     * Name of the filter collection.
     */
    name: string;
    /**
     * Filters included in the filter collection.
     */
    filters: Filter[];
}
/**
 * Interface for a filter.
 */
export interface Filter {
    /**
     * Name of the filter
     */
    name: string;
    /**
     * Function executed by the filter.
     */
    function: (...args: any[]) => any;
}
/**
 * Interface for a preset.
 */
export interface Preset {
    /**
     * Name of the preset.
     */
    name: string;
    /**
     * Filter collections used by the preset.
     */
    filterCollections: FilterCollection[];
    /**
     * Globals provided by the preset.
     */
    globals: Global[];
    /**
     * Path to the directory of the templates used by the preset.
     */
    templatesDir: string;
    /**
     * Tests provided by the preset.
     */
    tests: Test[];
}
/**
 * Interface for a global.
 */
export interface Global {
    /**
     * Name of the global.
     */
    name: string;
    /**
     * Value of the global.
     */
    value: any;
}
/**
 * Interface for a test.
 */
export interface Test {
    /**
     * Name of the test.
     */
    name: string;
    /**
     * Function executed by the test.
     */
    function: (first: any, second: any) => boolean;
}
/**
 * This function activates a filter collection by its name.
 * @param filterCollectionName The name of the filter collection to be activated.
 * @param env The nunjucks environment into which the filters should be loaded.
 */
export declare function activateFilterCollection(filterCollectionName: string, env: nunjucks.Environment): Promise<void>;
/**
 * This function returns a preset by its name.
 * @param presetName The name of the Preset.
 */
export declare function loadPreset(presetName: string): Promise<Preset>;
/**
 * This function activates a preset.
 * @param preset The Preset to be activated.
 * @param env The nunjucks environment the filters, tests and globals of the preset
 * should be loaded into.
 */
export declare function activatePreset(preset: Preset, env: nunjucks.Environment): Promise<void>;
//# sourceMappingURL=addon.d.ts.map